# Generated by Django 4.1.3 on 2022-11-19 12:51

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('theme_material_kit', '0001_initial'),
    ]

    operations = [
        migrations.DeleteModel(
            name='Test',
        ),
    ]
