{% load static %}

<!--   Core JS Files   -->
<script src="{% static "assets/js/core/popper.min.js" %}" type="text/javascript"></script>
<script src="{% static "assets/js/core/bootstrap.min.js" %}" type="text/javascript"></script>
<script src="{% static "assets/js/plugins/perfect-scrollbar.min.js" %}"></script>

<!-- Control Center for Material UI Kit: parallax effects, scripts for the example pages etc -->
<!--  Google Maps Plugin    -->

<script src="https://maps.googleapis.com/maps/api/js?key=AIzaSyDTTfWur0PDbZWPr7Pmq8K3jiDp0_xUziI"></script>
<script src="{% static "assets/js/material-kit.min.js" %}?v=3.1.0" type="text/javascript"></script>