// =========================================================
// * Material Kit 3 - v3.1.0
// =========================================================

// * Product Page: https://www.creative-tim.com/product/material-kit
// * Copyright 2024 Creative Tim (https://www.creative-tim.com)

// Coded by www.creative-tim.com

// =========================================================

// * The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.

// Bootstrap Functions
@import "material-kit/bootstrap/functions";

// Custom Variables
@import "material-kit/custom/variables";

// Theme Variables
@import "material-kit/variables";

// Bootstrap Core
@import "material-kit/bootstrap/bootstrap";

// Theme Core
@import "material-kit/theme";

// Custom Variables
@import "material-kit/custom/styles";
