<!DOCTYPE html>
<html lang="en" itemscope itemtype="http://schema.org/WebPage">

<head>
    {% include "includes/head.html" %}
    {% block extra_style %}{% endblock extra_style %}
</head>

<body class="{% block body %}{% endblock body %}">

    {% block navigation %}
        {% include "includes/navigation.html" %}
    {% endblock navigation %}

    {% block content %}{% endblock content %}

    {% block footer %}
        {% include "includes/footer.html" %}
    {% endblock footer %}

    {% include "includes/scripts.html" %}
    {% block extra_js %}{% endblock extra_js %}

</body>
</html>