{% load static %}

<meta charset="utf-8" />
<meta name="viewport" content="width=device-width, initial-scale=1, shrink-to-fit=no">
<link rel="apple-touch-icon" sizes="76x76" href="{% static "assets/img/apple-icon.png" %}">
<link rel="icon" type="image/png" href="{% static "assets/img/favicon.png" %}">

<title>Django Material Kit - Open-Source Starter</title>

<link rel="canonical" href="https://app-generator.dev/product/material-kit/django/" />

<!--     Fonts and icons     -->
<link rel="stylesheet" type="text/css" href="https://fonts.googleapis.com/css?family=Inter:300,400,500,600,700,900" />

<!-- Nucleo Icons -->
<link href="{% static "assets/css/nucleo-icons.css" %}" rel="stylesheet" />
<link href="{% static "assets/css/nucleo-svg.css" %}" rel="stylesheet" />

<!-- Font Awesome Icons -->
<script defer src="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.7.0/js/all.min.js" crossorigin="anonymous"></script>

<!-- Material Icons -->
<link rel="stylesheet" href="https://fonts.googleapis.com/css2?family=Material+Symbols+Rounded:opsz,wght,FILL,GRAD@24,400,0,0" />

<!-- CSS Files -->
<link id="pagestyle" href="{% static "assets/css/material-kit.css" %}?v=3.1.0" rel="stylesheet" />